@@ -181,7 +181,14 @@ ADSSMod = function(parameters) {
                            "Number of cores for parallel calculations (ncores)",
                            c("Value"),
                            "int",
-                           NA) 
+                           NA)
+
+    if (!is.doRGN && ncores > 1) {
+      warning("Please install the doRNG package to use multi-core simulation. Only one core will be used.")
+      ncores = 1
+    }
+
+    parameters$ncores = ncores
     # nocov end
   } else {
     parameters$ncores = 1
